﻿#_____________________________________________________________________________________
#
# Exempelkod för att hämta data från prognosdatabasen (prognos.konj.se)
# Example code for fetching data from the forecast database (prognos.konj.se)
#
# Du behöver installera pyjstat, skriv följande i kommandotolken
# You need to install pyjstat, in the command prompt write the following
#
# py -m pip install pyjstat
#_____________________________________________________________________________________

#_____________________________________________________________________________________

# Importera paket
# Import package
from pyjstat import pyjstat
import requests
from matplotlib import pyplot as plt
import pandas as pd

#_____________________________________________________________________________________

# Hämta årlig data från prognosdatabasen, efter att en tabell har genererats
# från databasen, är URL:en och den faktiska JSON-förfrågan belägna längst ner

# Fetch annual data from the forecast database, after a table has been generated
# from the database, the URL and the actual JSON query are located at the bottom.

# Ange URL:en
# Input the URL
POST_URL = 'https://prognos.konj.se:443/PxWeb/api/v1/sv/SenastePrognosen/f09_bnpkonsumtioninvesteringarochutrikeshandel/F0901.px'

# Ange JSON-förfrågan
# Input the JSON query
payload = {
  "query": [
    {
      "code": "variabel",
      "selection": {
        "filter": "item",
        "values": [
          "F0901Nbnpmp"
        ]
      }
    },
    {
      "code": "enhet",
      "selection": {
        "filter": "item",
        "values": [
          "F"
        ]
      }
    },
    {
      "code": "period",
      "selection": {
        "filter": "item",
        "values": [
          "2007",
          "2008",
          "2009",
          "2010",
          "2011",
          "2012",
          "2013",
          "2014",
          "2015",
          "2016",
          "2017",
          "2018",
          "2019",
          "2020",
          "2021",
          "2022",
          "2023",
          "2024",
          "2025",
          "2026",
          "2027"
        ]
      }
    }
  ],
  "response": {
    # Observera att 'format':'px' har ändrats till JSON-stat
    # Note that 'format':'px' has been changed to JSON-stat
    "format": "json-stat"
  }
}

#_____________________________________________________________________________________

# Ladda data
# Load data

response = requests.post(POST_URL,json = payload)
print(response)

dataset = pyjstat.Dataset.read(response.text)
df = dataset.write('dataframe')
print(df.head())

# _____________________________________________________________________________________

# Skapa graf
# Create graph

# Ändra formatet på perioden
# Change the format of the period
df["period"] = pd.to_datetime(df["period"]) #, format = "%YM%m")

# Ändra enheten från miljoner SEK till miljarder SEK för en bättre utseende i den provisoriska grafen
# Change the unit from millions SEK to billions SEK for a better appearance in the sample graph
df["value"] = df["value"] / 1000

# Skapa graf
# Create graph
plt.figure(figsize = (8,6),dpi=100)
plt.plot(df["period"],df["value"])

# Ändra bakgrundsfärg för prognosår som börjar från 2024
# Change background color for forecast years starting from 2024
plt.axvspan('2024', '2027', color='Grey', alpha=0.4, label='Highlight')
plt.figtext(0.775,0.5, 'Prognos')
plt.grid(axis = 'y', color = "lightgrey", alpha=0.3)

# Lägg till titel och visa diagramet
# Add title and show the graph

plt.title("BNP Sverige, mdkr, fasta priser \n" "2024-2027 = senaste prognosen")
plt.show()
